@@ -1,4 +1,4 @@
-/* $Id: commands.c,v 1.14 2002/02/23 13:16:30 mhe Exp $
+/* $Id: commands.c,v 1.16 2002/12/05 22:13:54 mhe Exp $
  *
  * commands.c --
  *
@@ -34,7 +34,7 @@ cmd_t cmds[] = {
 	CMD(alias, 0,0,1, cpAlias),
 	CMD(bookmark, 0,0,1, cpBookmark),
 	CMD(cache, 0,0,1, cpNone),
-	CMD(cat, 0,0,1, cpRemoteFile),
+	CMD(cat, 0,0,0, cpRemoteFile),
 	CMD(cd, 0,0,1, cpRemoteDir),
 	CMD(cdup, 0,0,1, cpNone),
 	CMD(chmod, 0,0,0, cpRemoteFile),
@@ -48,21 +48,21 @@ cmd_t cmds[] = {
 	CMD(list, 0,0,1, cpRemoteFile),
 	CMD(lpwd, 0,0,1, cpNone),
 	CMD(ls, 0,0,0, cpRemoteFile),
-	CMD(ltag, 0,0,1, cpLocalFile),
+	CMD(ltag, 0,0,0, cpLocalFile),
 	CMD(luntag, 0,0,0, cpLocalTaglist),
 	CMD(mkdir, 0,0,1, cpNone),
 	CMD(nlist, 0,0,1, cpRemoteFile),
 	CMD(nop, 0,0,1, cpNone),
 	CMD(idle, 0,0,1, cpNone),
 	CMD(open, 0,0,1, cpHostname),
-	CMD(put, 0,0,1, cpLocalFile),
+	CMD(put, 0,0,0, cpLocalFile),
 	CMD(pwd, 0,0,1, cpNone),
 	CMD(quit, 0,0,1, cpNone),
 	CMD(quote, 0,0,1, cpNone),
 	CMD(mv, 0,0,1, cpRemoteFile),
-	CMD(reopen, 1, 1, 1, cpNone),
+	CMD(reopen, 1,1,1, cpNone),
 	CMD(rhelp, 1,0,1, cpNone),
-	CMD(rm, 0,0,1, cpRemoteFile),
+	CMD(rm, 0,0,0, cpRemoteFile),
 	CMD(rmdir, 0,0,1, cpRemoteDir),
 	CMD(rstatus, 0,0,1, cpRemoteFile),
 	CMD(set, 0,0,1, cpVariable),
@@ -74,15 +74,15 @@ cmd_t cmds[] = {
 	CMD(system, 0,0,0, cpNone),
 	CMD(tag, 0,0,0, cpRemoteFile),
 	CMD(unalias, 0,0,1, cpAlias),
-	CMD(untag, 0,0,1, cpTaglist),
+	CMD(untag, 0,0,0, cpTaglist),
 	CMD(url, 0,0,1, cpNone),
 	CMD(user, 0,0,1, cpNone),
 	CMD(version, 0,0,1, cpNone),
 	CMD(warranty, 0,0,1, cpNone),
-#if defined(KRB4) || defined(KRB5)
+#ifdef HAVE_KERBEROS
 	CMD(prot, 1,1,1, cpNone),
 #endif
-#ifdef KRB4
+#ifdef HAVE_KRB4
 	CMD(afslog, 0,0,1, cpNone),
 	CMD(klist, 0,0,1, cpNone),
 	CMD(kauth, 0,0,1, cpNone),
@@ -693,7 +693,7 @@ void cmd_status(int argc, char **argv)
 		puts(_("not connected"));
 	if(ftp_loggedin())
 		printf(_("logged in as '%s'\n"), ftp->url->username);
-#if defined(KRB4) || defined(KRB5)
+#ifdef HAVE_KERBEROS
 	if(ftp_connected())
 		sec_status();
 #endif
@@ -706,15 +706,6 @@ void cmd_site(int argc, char **argv)
 {
 	char *e;
 
-#if 0
-	OPT_HELP("Send site specific command.  Usage:\n"
-			 "  site [options] [command]\n"
-			 "Options:\n"
-			 "  -h, --help    show this help\n"
-			 "[command] should be a valid SITE argument\n"
-			 "try 'site help' or 'rhelp site' for more information\n");
-#endif
-
 	minargs_nohelp(1);
 	need_connected();
 
