@@ -1,4 +1,4 @@
-/* $Id: completion.c,v 1.7 2001/05/13 11:51:23 mhe Exp $
+/* $Id: completion.c,v 1.9 2002/11/04 14:16:13 mhe Exp $
  *
  * completion.c -- readline completion functions
  *
@@ -166,15 +166,21 @@ static char *remote_completion_function(const char *text, int state)
 			else
 				merge_fmt = "%s/%s";
 		}
-		rl_insert_text("..."); /* show dots while waiting, like ncftp */
-		rl_redisplay();
+		if(gvWaitingDots) {
+			rl_insert_text("..."); /* show dots while waiting, like ncftp */
+			rl_redisplay();
+		}
+		
 		ap = ftp_path_absolute(dir);
 		rdir = ftp_cache_get_directory(ap);
 		dir_is_cached = (rdir != 0);
 		if(!rdir)
 			rdir = ftp_read_directory(ap);
 		xfree(ap);
-		rl_do_undo(); /* remove the dots */
+
+		if(gvWaitingDots)
+			rl_do_undo(); /* remove the dots */
+
 		if(!dir_is_cached && ftp_get_verbosity() >= vbCommand)
 			rl_forced_update_display();
 
@@ -298,7 +304,7 @@ static char *taglist_completion_function(const char *text, int state)
 		rfile *f = (rfile *)lip->data;
 		lip = lip->next;
 		if(strncmp(f->path, text, len) == 0)
-			return bash_backslash_quote(f->path);
+			return xstrdup(f->path);
 	}
 	return 0;
 }
@@ -325,7 +331,7 @@ static char *local_taglist_completion_function(const char *text, int state)
 		char *p = (char *)lip->data;
 		lip = lip->next;
 		if(strncmp(p, text, len) == 0)
-			return bash_backslash_quote(p);
+			return xstrdup(p); /* bash_backslash_quote(p); */
 	}
 	return 0;
 }
