@@ -1,4 +1,4 @@
-/* $Id: ftp.c,v 1.31 2002/04/07 18:10:38 mhe Exp $
+/* $Id: ftp.c,v 1.35 2002/12/05 22:13:30 mhe Exp $
  *
  * ftp.c -- low(er) level FTP stuff
  *
@@ -296,9 +296,12 @@ int ftp_open_url(url_t *urlp, bool reset_vars)
 	 * need to do this here, 'cause host_lookup() sets it to 21
 	 * (default port for vanilla FTP)
 	 */
-	if(urlp->protocol && strcmp(urlp->protocol, "ssh") == 0
-		&& urlp->port == -1)
-		urlp->port = 22; /* default SSH port */
+	if(urlp->protocol) {
+		if(strcmp(urlp->protocol, "sftp") == 0)
+			url_setprotocol(urlp, "ssh");
+		if(strcmp(urlp->protocol, "ssh") == 0 && urlp->port == -1)
+			urlp->port = 22; /* default SSH port */
+	}
 
 	ftp->host = host_create(use_proxy ? gvProxyUrl : urlp);
 
@@ -796,15 +799,10 @@ static const char *secext_name(const char *mech)
 		const char *short_name;
 		const char *real_name;
 	} names[] = {
-#ifdef KRB4
 		{"krb4", "KERBEROS_V4"},
-#endif
-#ifdef KRB5
 		{"krb5", "GSSAPI"},
-#endif
-#ifdef SSL
-		{"ssl", "SSL"},
-#endif
+		{"gssapi", "GSSAPI"},
+/*		{"ssl", "SSL"},*/
 		{"none", "none"},
 		{0, 0}
 	};
@@ -820,11 +818,11 @@ static const char *secext_name(const char *mech)
 
 static bool mech_unsupported(const char *mech)
 {
-#ifndef KRB4
+#ifndef HAVE_KRB4
 	if(strcasecmp(mech, "KERBEROS_V4") == 0)
 		return true;
 #endif
-#ifndef KRB5
+#ifndef HAVE_KRB5
 	if(strcasecmp(mech, "GSSAPI") == 0)
 		return true;
 #endif
@@ -1315,6 +1313,7 @@ rdirectory *ftp_read_directory(const char *path)
 	char *tmpfilename, *e;
 	bool _failed = false;
 	char *dir;
+	bool is_mlsd = false;
 
 	if(ftp->ssh_pid)
 		return ssh_read_directory(path);
@@ -1357,6 +1356,7 @@ rdirectory *ftp_read_directory(const char *path)
 	}
 
 	if(ftp->has_mlsd_command) {
+		is_mlsd = true;
 #if 0
 		/* PureFTPd (1.0.11) doesn't recognize directory arguments
 		 * with spaces, not even quoted, it just chops the argument
@@ -1377,8 +1377,10 @@ rdirectory *ftp_read_directory(const char *path)
 		if(_failed && ftp->code == ctError)
 			ftp->has_mlsd_command = false;
 	}
-	if(!ftp->has_mlsd_command)
+	if(!ftp->has_mlsd_command) {
 		_failed = (ftp_list("LIST", 0, fp) != 0);
+		is_mlsd = false;
+	}
 
 	if(!is_curdir)
 		ftp_cmd("CWD %s", ftp->curdir);
@@ -1389,7 +1391,7 @@ rdirectory *ftp_read_directory(const char *path)
 	rewind(fp);
 
 	rdir = rdir_create();
-	if(rdir_parse(rdir, fp, dir) != 0) {
+	if(rdir_parse(rdir, fp, dir, is_mlsd) != 0) {
 		rdir_destroy(rdir);
 		goto failed;
 	}
