@@ -1,4 +1,4 @@
-/* $Id: ftp.h,v 1.9 2001/05/12 18:44:04 mhe Exp $
+/* $Id: ftp.h,v 1.14 2002/12/02 14:32:21 mhe Exp $
  *
  * ftp.h -- lower level FTP stuff
  *
@@ -24,6 +24,7 @@
 #include "rfile.h"
 #include "ftpsigs.h"
 #include "rglob.h"
+#include "args.h"
 
 #define MAXREPLY 512      /* max size of (one line of) reply string */
 
@@ -36,7 +37,7 @@ typedef enum {
 	putNormal,
 	putAppend,
 	putUnique,
-	putResume,
+	putResume
 } putmode_t;
 
 typedef enum {
@@ -80,13 +81,15 @@ typedef enum {
 	ltUnknown,
 	ltUnix,
 	ltDos,
-	ltEplf
+	ltEplf,
+	ltMlsd
 } LIST_t;
 
 typedef enum {
 	mechNone,
 	mechKrb4,
-	mechKrb5
+	mechKrb5,
+	mechSSL
 } mech_type_t;
 
 typedef struct transfer_info
@@ -119,7 +122,7 @@ typedef struct Ftp
 
 	pid_t ssh_pid;           /* process id of ssh program, or 0 if
 							  * ssh is not in use */
-	char **ssh_args;
+	args_t *ssh_args;
 	int ssh_in, ssh_out;     /* file descriptors for use by ssh */
 	int ssh_version;
 	unsigned int ssh_id;
@@ -146,6 +149,7 @@ typedef struct Ftp
 	bool has_stou_command;
 	bool has_site_chmod_command;
 	bool has_site_idle_command;
+	bool has_mlsd_command;
 
 	long restart_offset;  /* next transfer will be restarted at this offset */
 
@@ -165,7 +169,7 @@ typedef struct Ftp
 	char * (*getuser_hook)(const char *prompt);
 	char * (*getpass_hook)(const char *prompt);
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	bool sec_complete;
 	enum protection_level data_prot;
 	enum protection_level command_prot;
@@ -229,6 +233,7 @@ void transfer_finished(void);
 int ftp_get_verbosity(void);
 void ftp_set_verbosity(int verbosity);
 void ftp_set_tmp_verbosity(int verbosity);
+int get_username(url_t *url, const char *guessed_username, bool isproxy);
 
 bool ftp_connected(void);
 bool ftp_loggedin(void);
@@ -273,6 +278,8 @@ time_t gmt_mktime(const struct tm *ts);
  */
 int ftp_maybe_isdir(rfile *fp);
 void ftp_pwd(void);
+char *perm2string(int perm);
+void ftp_get_feat(void);
 
 /* in lscolors.h */
 void init_colors(void);
