@@ -1,21 +1,14 @@
-/* lscolors.c -- parsing of env variable LS_COLORS
+/* $Id: lscolors.c,v 1.4 2002/11/07 18:08:15 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * lscolors.c -- parsing of env variable LS_COLORS
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -56,12 +49,7 @@ void init_colors(void)
 	if(!p)
 		p = getenv("LS_COLOURS");
 
-	if(p && !*p) {
-		xfree(p);
-		p = 0;
-	}
-
-	if(p) {
+	if(p && *p) {
 		org = p = xstrdup(p);
 		n = strqnchr(p, ':')+2;
 		clrs = (lscolor *)xmalloc(n * sizeof(lscolor));
@@ -71,9 +59,9 @@ void init_colors(void)
 			clrs[i].msk = xstrdup(q);
 			q = strqsep(&e, ':');
 			clrs[i].clr = xstrdup(q);
-			
+
 			e = strqsep(&p, ':');
-			
+
 			if(strcmp(clrs[i].msk, "di")==0) /* directory */
 				diclr = clrs[i].clr;
 			else if(strcmp(clrs[i].msk, "ln")==0) /* link */
@@ -114,7 +102,7 @@ void rfile_parse_colors(rfile *f)
 	int i;
 
 	/* colors should already been initialized by init_colors */
-	
+
 	e = 0;
 	if(risdir(f))
 		e = diclr;
