@@ -1,4 +1,4 @@
-/* $Id: get.c,v 1.11 2001/10/12 08:52:30 mhe Exp $
+/* $Id: get.c,v 1.15 2002/12/02 12:21:18 mhe Exp $
  *
  * get.c -- get file(s) from remote
  *
@@ -23,6 +23,7 @@
 #include "commands.h"
 #include <modechange.h>  /* in ../lib/ */
 #include "utils.h"
+#include "bashline.h"
 
 #ifdef HAVE_REGEX_H
 # include <regex.h>
@@ -33,6 +34,7 @@ static bool get_owbatch = false;
 static bool get_delbatch = false;
 static struct mode_change *cmod = 0;
 static gid_t group_change = -1;
+static bool get_skip_empty = false;
 
 static char *get_glob_mask = 0;
 static char *get_dir_glob_mask = 0;
@@ -57,6 +59,7 @@ static void print_get_syntax(void)
 			 "      --dir-rx-mask=REGEXP\n"
 			 "                       enter only directories matching REGEXP pattern\n"
 			 "  -f, --force          overwrite existing destinations, never prompt\n"
+			 "  -e, --skip-empty     skip empty files\n"
 			 "  -H, --nohup          transfer files in background (nohup mode), quits yafc\n"
 			 "  -i, --interactive    prompt before each transfer\n"
 			 "  -L, --logfile=FILE   use FILE as logfile instead of ~/.yafc/nohup/nohup.<pid>\n"
@@ -77,6 +80,15 @@ static void print_get_syntax(void)
 			 "      --help           display this help\n"));
 }
 
+static bool get_exclude_func(rfile *f)
+{
+	if(risdotdir(f))
+		return true;
+	if(get_skip_empty == true && !risdir(f) && f->size == 0)
+	   return true;
+	return false;
+}
+
 /* just gets the file SRC and store in local file DEST
  * doesn't parse any LIST output
  * returns 0 on success, else -1
@@ -180,10 +192,25 @@ static int getfile(const rfile *fi, unsigned int opt,
 		char *apath = base_dir_xptr(fi->path);
 		asprintf(&dest, "%s%s/%s", output, apath, destname);
 		xfree(apath);
-	} else if(test(opt, GET_OUTPUT_FILE))
-		dest = xstrdup(output);
-	else
-		asprintf(&dest, "%s/%s", output, destname);
+	} else {
+		/* check if -o option is given, if GET_OUTPUT_FILE is set, we only
+		 * transfer one file and output is set to the filename. However, if
+		 * the destination already exists and is a directory, we assume
+		 * that the user meant a directory */
+
+		int dest_is_file = test(opt, GET_OUTPUT_FILE);
+
+		if(stat(output, &sb) == 0) {
+			if(S_ISDIR(sb.st_mode)) {
+				dest_is_file = false;
+			}
+		}
+
+		if(dest_is_file)
+			dest = xstrdup(output);
+		else
+			asprintf(&dest, "%s/%s", output, destname);
+	}
 
 	/* make sure destination directory exists */
 	{
@@ -205,8 +232,7 @@ static int getfile(const rfile *fi, unsigned int opt,
 					m = mode_adjust(m, cmod);
 					if(chmod(destdir, m) != 0)
 						perror(destdir);
-				}
-			}
+				}			}
 			if(test(opt, GET_CHGRP)) {
 				if(chown(destdir, -1, group_change) != 0)
 					perror(dest);
@@ -244,10 +270,20 @@ static int getfile(const rfile *fi, unsigned int opt,
 			}
 		} else if(!test(opt, GET_RESUME)) {
 			if(!get_owbatch && !gvSighupReceived) {
-				int a = ask(ASKYES|ASKNO|ASKUNIQUE|ASKCANCEL|ASKALL|ASKRESUME,
-							ASKRESUME,
-							_("Local file '%s' exists, overwrite?"),
-							shortpath(dest, 42, gvLocalHomeDir));
+				struct tm *fan = gmtime(&sb.st_mtime);
+				time_t ft = ftp_filetime(fi->path);
+				int a;
+				char *e;
+
+				sb.st_mtime = gmt_mktime(fan);
+				e = xstrdup(ctime(&sb.st_mtime));
+				a = ask(ASKYES|ASKNO|ASKUNIQUE|ASKCANCEL|ASKALL|ASKRESUME,
+						ASKRESUME,
+						_("Local file '%s' exists\nLocal: %ld bytes, %sRemote: %ld bytes, %sOverwrite?"),
+						shortpath(dest, 42, gvLocalHomeDir),
+						sb.st_size, e ? e : "unknown date",
+						ftp_filesize(fi->path), ctime(&ft));
+				xfree(e);
 				if(a == ASKCANCEL) {
 					get_quit = true;
 					return 0;
@@ -342,6 +378,18 @@ static int getfile(const rfile *fi, unsigned int opt,
 
 static bool get_batch = false;
 
+int get_sort_func(const void *a, const void *b)
+{
+   const rfile *ra = (const rfile *)a;
+   const rfile *rb = (const rfile *)b;
+   bool tfa = transfer_first(ra->path);
+   bool tfb = transfer_first(rb->path);
+
+   if(tfa)
+	  return tfb ? 0 : -1;
+   return tfb ? 1 : 0;
+}
+
 static void getfiles(list *gl, unsigned int opt, const char *output)
 {
 	listitem *li;
@@ -350,6 +398,8 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
 	char *link = 0;
 	int r;
 
+	list_sort(gl, get_sort_func, false);
+
 	li = gl->first;
 	while(li && !get_quit) {
 		fp = (rfile *)li->data;
@@ -452,6 +502,7 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
 					)
 					{
 					} else {
+						char *q_recurs_mask;
 
 						if(!test(opt, GET_PARENTS))
 							asprintf(&recurs_output, "%s/%s",
@@ -461,7 +512,9 @@ static void getfiles(list *gl, unsigned int opt, const char *output)
 									 output ? output : ".");
 						rgl = rglob_create();
 						asprintf(&recurs_mask, "%s/*", opath);
-						rglob_glob(rgl, recurs_mask, true, true, 0);
+						q_recurs_mask = bash_backslash_quote(recurs_mask);
+						rglob_glob(rgl, q_recurs_mask, true, true, get_exclude_func);
+						xfree(q_recurs_mask);
 						if(list_numitem(rgl) > 0)
 							getfiles(rgl, opt, recurs_output);
 						if(test(opt, GET_PRESERVE))
@@ -527,6 +580,7 @@ void cmd_get(int argc, char **argv)
 		{"dir-rx-mask", required_argument, 0, '4'},
 #endif
 		{"interactive", no_argument, 0, 'i'},
+		{"skip-empty", no_argument, 0, 'e'},
 		{"force", no_argument, 0, 'f'},
 		{"logfile", required_argument, 0, 'L'},
 		{"mask", required_argument, 0, 'm'},
@@ -574,8 +628,10 @@ void cmd_get(int argc, char **argv)
 	}
 #endif
 
+	get_skip_empty = false;
+
 	optind = 0; /* force getopt() to re-initialize */
-	while((c=getopt_long(argc, argv, "abHc:dDio:fL:tnpPvqrRsuT:m:M:",
+	while((c=getopt_long(argc, argv, "abHc:dDeio:fL:tnpPvqrRsuT:m:M:",
 						 longopts, 0)) != EOF)
 	{
 		switch(c) {
@@ -623,6 +679,10 @@ void cmd_get(int argc, char **argv)
 		  case 'd':
 			opt |= GET_NO_DEREFERENCE;
 			break;
+		   case 'e':
+			  opt |= GET_SKIP_EMPTY;
+			  get_skip_empty = true;
+			  break;
 		case '3': /* --dir-mask=GLOB */
 			xfree(get_dir_glob_mask);
 			get_dir_glob_mask = xstrdup(optarg);
@@ -673,7 +733,7 @@ void cmd_get(int argc, char **argv)
 #endif
 		  case 'o':
 			get_output = tilde_expand_home(optarg, gvLocalHomeDir);
-			stripslash(get_output);
+			/*stripslash(get_output);*/
 			unquote(get_output);
 			break;
 		  case 'v':
@@ -742,7 +802,7 @@ void cmd_get(int argc, char **argv)
 	gl = rglob_create();
 	while(optind < argc) {
 		stripslash(argv[optind]);
-		if(rglob_glob(gl, argv[optind], true, true, 0) == -1)
+		if(rglob_glob(gl, argv[optind], true, true, get_exclude_func) == -1)
 			fprintf(stderr, _("%s: no matches found\n"), argv[optind]);
 		optind++;
 	}
@@ -768,7 +828,12 @@ void cmd_get(int argc, char **argv)
 	if(get_output && !test(opt, GET_RECURSIVE) && list_numitem(gl) +
 	   (test(opt, GET_TAGGED) ? list_numitem(ftp->taglist) : 0) == 1)
 		{
-			opt |= GET_OUTPUT_FILE;
+			/* if the argument to --output ends with a slash, we assume the
+			 * user wants the destination to be a directory
+			 */
+			char *e = strrchr(get_output, 0);
+			if(e && e[-1] != '/')
+				opt |= GET_OUTPUT_FILE;
 		}
 
 	gvInTransfer = true;
