@@ -1,4 +1,4 @@
-/* $Id: gvars.h,v 1.11 2001/05/13 12:24:25 mhe Exp $
+/* $Id: gvars.h,v 1.14 2002/12/02 12:38:48 mhe Exp $
  *
  * gvars.h -- global variables
  *
@@ -18,6 +18,9 @@
 #include "ftp.h"
 #include "linklist.h"
 
+/* time (in seconds) before a cached directory times out, 0 == never */
+extern int gvCacheTimeout;
+
 /* list of Ftp objects */
 extern list *gvFtpList;
 
@@ -34,6 +37,9 @@ extern bool gvAutologin;
 /* do reverse DNS lookups? */
 extern bool gvReverseDNS;
 
+/* add ... while waiting for a completion? */
+extern bool gvWaitingDots;
+
 /* path to the SSH program */
 extern char *gvSSHProgram ;
 
@@ -114,10 +120,14 @@ extern list *gvAliases;
 /* list of shell-glob-format filemasks to transfer in ascii mode */
 extern list *gvAsciiMasks;
 
+/* list of shell-glob-format filemasks to transfer before other files */
+extern list *gvTransferFirstMasks;
+
 /* don't include "." and ".." in completions */
 extern bool gvCompletionSkipDotdirs;
 
 extern int gvAutoBookmark;
+extern int gvAutoBookmarkUpdate;
 extern bool gvAutoBookmarkSilent;
 extern bool gvAutoBookmarkSavePasswd;
 
