@@ -1,4 +1,4 @@
-/* $Id: put.c,v 1.10 2001/05/13 20:06:55 mhe Exp $
+/* $Id: put.c,v 1.14 2002/12/02 12:21:19 mhe Exp $
  *
  * put.c -- upload files
  *
@@ -22,6 +22,7 @@
 #include "commands.h"
 #include "lglob.h"
 #include "utils.h"
+#include "bashline.h"
 
 #ifdef HAVE_REGEX_H
 # include <regex.h>
@@ -31,6 +32,7 @@ static bool put_batch = false;
 static bool put_owbatch = false;
 static bool put_delbatch = false;
 static bool put_quit = false;
+static bool put_skip_empty = false;
 
 static char *put_glob_mask = 0;
 static char *put_dir_glob_mask = 0;
@@ -51,6 +53,7 @@ static void print_put_syntax(void)
 			 "      --dir-mask=GLOB  enter only directories matching GLOB pattern\n"
 			 "      --dir-rx-mask=REGEXP\n"
 			 "                       enter only directories matching REGEXP pattern\n"
+			 "  -e, --skip-empty     skip empty files\n"
 			 "  -f, --force          overwrite existing destinations, never prompt\n"
 			 "  -H, --nohup          transfer files in background (nohup mode), quits yafc\n"
 			 "  -i, --interactive    prompt before transferring each file\n"
@@ -72,6 +75,19 @@ static void print_put_syntax(void)
 			 "      --help           display this help\n"));
 }
 
+static bool put_exclude_func(char *path)
+{
+	if(lglob_exclude_dotdirs(path))
+		return true;
+	if(put_skip_empty == true) {
+		struct stat stbuf;
+		stat(path, &stbuf);
+		if(!S_ISDIR(stbuf.st_mode) && stbuf.st_size == 0)
+			return true;
+	}
+	return false;
+}
+
 static int do_the_put(const char *src, const char *dest,
 					  putmode_t how, unsigned opt)
 {
@@ -117,7 +133,7 @@ static void putfile(const char *path, struct stat *sb,
 	char *dest, *dpath;
 	int r;
 	bool dir_created;
-	char *dest_dir;
+	char *dest_dir, *q_dest_dir;
 
 	if((put_glob_mask && fnmatch(put_glob_mask, base_name_ptr(path),
 								 FNM_EXTMATCH) == FNM_NOMATCH)
@@ -145,7 +161,9 @@ static void putfile(const char *path, struct stat *sb,
 	/* make sure destination directory exists */
 	dpath = base_dir_xptr(dest);
 	dest_dir = ftp_path_absolute(dpath);
-	r = ftp_mkpath(dest_dir);
+	q_dest_dir = bash_backslash_quote(dest_dir);
+	r = ftp_mkpath(q_dest_dir);
+	xfree(q_dest_dir);
 	xfree(dest_dir);
 	if(r == -1) {
 		transfer_mail_msg(_("failed to create directory %s\n"), dest_dir);
@@ -187,10 +205,23 @@ static void putfile(const char *path, struct stat *sb,
 		}
 		else if(!test(opt, PUT_RESUME)) {
 			if(!put_owbatch) {
-				int a = ask(ASKYES|ASKNO|ASKUNIQUE|ASKCANCEL|ASKALL|ASKRESUME,
-							ASKRESUME,
-							_("File '%s' exists, overwrite?"),
-							shortpath(dest, 42, ftp->homedir));
+				struct tm *fan = gmtime(&sb->st_mtime);
+				time_t ft;
+				int a;
+				rfile *f;
+				char *e;
+
+				f = ftp_get_file(dest);
+				ft = ftp_filetime(f->path);
+				sb->st_mtime = gmt_mktime(fan);
+				e = xstrdup(ctime(&sb->st_mtime));
+				a = ask(ASKYES|ASKNO|ASKUNIQUE|ASKCANCEL|ASKALL|ASKRESUME,
+						ASKRESUME,
+						_("Remote file '%s' exists\nLocal: %ld bytes, %sRemote: %ld bytes, %sOverwrite?"),
+						shortpath(dest, 42, ftp->homedir),
+						sb->st_size, e ? e : "unknown date",
+						ftp_filesize(f->path), ctime(&ft));
+				xfree(e);
 				if(a == ASKCANCEL) {
 					put_quit = true;
 					xfree(dest);
@@ -256,13 +287,25 @@ static void putfile(const char *path, struct stat *sb,
 	}
 }
 
-static void putfiles(const list *gl, unsigned opt, const char *output)
+static int put_sort_func(const void *a, const void *b)
+{
+   bool tfa = transfer_first((char *)a);
+   bool tfb = transfer_first((char *)b);
+
+   if(tfa)
+	  return tfb ? 0 : -1;
+   return tfb ? 1 : 0;
+}
+
+static void putfiles(list *gl, unsigned opt, const char *output)
 {
 	struct stat sb;
 	char *path = 0;
 	const char *file;
 	listitem *li;
 
+	list_sort(gl, put_sort_func, false);
+
 	for(li=gl->first; li && !put_quit; li=li->next) {
 
 		if(!ftp_connected())
@@ -329,8 +372,8 @@ static void putfiles(const list *gl, unsigned opt, const char *output)
 
 						asprintf(&recurs_mask, "%s/*", path);
 						rgl = lglob_create();
-						r = lglob_glob(rgl,
-									   recurs_mask, lglob_exclude_dotdirs);
+						r = lglob_glob(rgl, recurs_mask, true,
+									   put_exclude_func);
 						xfree(recurs_mask);
 
 						if(list_numitem(rgl) > 0)
@@ -385,6 +428,7 @@ void cmd_put(int argc, char **argv)
 #ifdef HAVE_REGEX
 		{"dir-rx-mask", required_argument, 0, '4'},
 #endif
+		{"skip-empty", no_argument, 0, 'e'},
 		{"force", no_argument, 0, 'f'},
 		{"nohup", no_argument, 0, 'H'},
 		{"interactive", no_argument, 0, 'i'},
@@ -428,9 +472,11 @@ void cmd_put(int argc, char **argv)
 	}
 #endif
 
+	put_skip_empty = false;
+
 	optind = 0; /* force getopt() to re-initialize */
 	while((c = getopt_long(argc, argv,
-						   "aDfHiL:no:pPqrRstvum:M:", longopts, 0)) != EOF)
+						   "aDefHiL:no:pPqrRstvum:M:", longopts, 0)) != EOF)
 	{
 		switch(c) {
 		case 'i':
@@ -439,6 +485,10 @@ void cmd_put(int argc, char **argv)
 		case 'f':
 			opt |= PUT_FORCE;
 			break;
+		   case 'e':
+			  opt |= PUT_SKIP_EMPTY;
+			  put_skip_empty = true;
+			  break;
 		case '3': /* --dir-mask=GLOB */
 			xfree(put_dir_glob_mask);
 			put_dir_glob_mask = xstrdup(optarg);
@@ -572,7 +622,7 @@ void cmd_put(int argc, char **argv)
 
 		f = tilde_expand_home(argv[optind], gvLocalHomeDir);
 		stripslash(f);
-		lglob_glob(gl, f, lglob_exclude_dotdirs);
+		lglob_glob(gl, f, true, put_exclude_func);
 		optind++;
 	}
 
